"""
:authors: two-it2022
:license: Apache License, Version 0.3, see LICENSE file

:copyright: (c) 2022 two-it2022
"""

from .sock import *
from .wikipedia import *
from .translate import *




__author__ = 'two-it2022'
__version__ = '0.0.3'
__email__ = 'kodland.group@gmail.com'
